@@ -18,7 +18,6 @@
 #       along with this program; if not, write to the Free Software
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
-
 """
 :mod:`pympress.extras` -- Manages the display of fancy extras such as annotations, videos and cursors
 -----------------------------------------------------------------------------------------------------
@@ -33,7 +32,7 @@ import os.path
 import gi
 import cairo
 gi.require_version('Gtk', '3.0')
-from gi.repository import Gtk, Gdk, GLib, Pango
+from gi.repository import Gtk, Gdk, GLib
 
 import mimetypes
 from collections import defaultdict
@@ -46,6 +45,8 @@ from pympress.media_overlays.base import VideoOverlay
 
 
 class TimingReport(builder.Builder):
+    """ Widget tracking and displaying hierachically how much time was spent in each page/section of the presentation.
+    """
     #: `list` of time at which each page was reached
     page_time = []
     #: `int` the time at which the clock was reset
@@ -64,32 +65,42 @@ class TimingReport(builder.Builder):
 
 
     def transition(self, page, time):
-        ''' Record a transition time between slides
+        """ Record a transition time between slides.
 
         Args:
             page (`int`): the page number of the current slide
             time (`int`): the number of seconds elapsed since the beginning of the presentation
-        '''
+        """
         if self.reset_time >= 0:
             self.reset_time = -1
-            self.page_time.clear()
+            del self.page_time[:]
         self.page_time.append((page, time))
 
 
     def reset(self, reset_time):
-        ''' A timer reset. Clear the history as soon as we start changing pages again.
-        '''
+        """ A timer reset. Clear the history as soon as we start changing pages again.
+        """
         self.reset_time = reset_time
 
 
+    @staticmethod
+    def format_time(secs):
+        """ Formats a number of seconds as `minutes:seconds`.
+
+        Returns:
+            `str`: The formatted time, with 2+ digits for minutes and 2 digits for seconds.
+        """
+        return '{:02}:{:02}'.format(*divmod(secs, 60))
+
+
     def show(self, current_time, doc_structure, page_labels):
-        ''' Show the popup with the timing infortmation
+        """ Show the popup with the timing infortmation.
 
         Args:
             current_time (`int`): the number of seconds elapsed since the beginning of the presentation
             doc_structure (`dict`): the structure of the document
             page_labels (`list`): the page labels for each of the pages
-        '''
+        """
         times = [time for page, time in self.page_time] + [current_time if self.reset_time < 0 else self.reset_time]
         durations = (e - s for e, s in zip(times[1:], times[:-1]))
 
@@ -117,12 +128,12 @@ class TimingReport(builder.Builder):
                     cur_info_pos['children'][-1]['duration'] += duration
                 else:
                     cur_info_pos['children'].append({'page': pos, 'title': item['title'], 'children': [],
-                                        'duration': duration, 'time': start_time})
+                                                     'duration': duration, 'time': start_time})
                 cur_info_pos = cur_info_pos['children'][-1]
 
             # add the actual page as a leaf node
             cur_info_pos['children'].append({'page': page, 'title': _('slide #') + page_labels[page],
-                                        'duration': duration, 'time': start_time})
+                                             'duration': duration, 'time': start_time})
 
 
         treemodel = self.timing_treeview.get_model()
@@ -134,9 +145,8 @@ class TimingReport(builder.Builder):
         dfs_info = [(None, infos)]
         while dfs_info:
             first_it, first = dfs_info.pop()
-            fmt = lambda val: '{:02}:{:02}'.format(*divmod(val, 60))
             last_col = '{} ({}/{})'.format(page_labels[first['page']], first['page'], len(page_labels))
-            row = [first['title'], fmt(first['time']), fmt(first['duration']), last_col]
+            row = [first['title'], self.format_time(first['time']), self.format_time(first['duration']), last_col]
             it = treemodel.append(first_it, row)
 
             if 'children' in first:
@@ -150,52 +160,26 @@ class TimingReport(builder.Builder):
 
 
 class Annotations(object):
-    #: The containing widget for the annotations
-    scrollable_treelist = None
-    #: Making the annotations list scroll if it's too long
+    """ Widget displaying a PDF’s text annotations.
+    """
+    #: The containing :class:`~Gtk.TextView` widget for the annotations
+    annotations_textview = None
+    #: :class:`~Gtk.ScrolledWindow` making the annotations list scroll if it's too long
     scrolled_window = None
-    #: :class:`~Gtk.CellRendererText` Text renderer for the annotations
-    annotation_renderer = None
 
     def __init__(self, builder):
-        """ Load the widgets and setup for the annotations' display.
-
-        Args:
-            builder (:class:`~pympress.builder.Builder`): A builder from which to load widgets
-        """
         super(Annotations, self).__init__()
         builder.load_widgets(self)
 
-        self.scrolled_window.set_hexpand(True)
-
 
     def add_annotations(self, annotations):
-        """ Insert text annotations into the tree view that displays them.
+        """ Add annotations to be displayed (typically on going to a new slide).
 
         Args:
             annotations (`list`): A list of strings, that are the annotations to be displayed
         """
-        prev_annots = self.scrollable_treelist.get_model()
-        if prev_annots:
-            prev_annots.clear()
-        list_annot = Gtk.ListStore(str)
-
-        for annot in annotations:
-            list_annot.append(('● ' + annot,))
-
-        self.scrollable_treelist.set_model(list_annot)
-
-
-    def on_configure_annot(self, widget, event):
-        """ Adjust wrap width in annotations when they are resized.
-
-        Args:
-            widget (:class:`~Gtk.Widget`):  the widget which was resized.
-            event (:class:`~Gdk.Event`):  the GTK event.
-        """
-        self.annotation_renderer.props.wrap_width = max(30, widget.get_allocated_width() - 10)
-        self.scrolled_window.queue_resize()
-        self.scrollable_treelist.get_column(0).queue_resize()
+        buf = self.annotations_textview.get_buffer()
+        buf.set_text('\n'.join(annotations))
 
 
     def on_scroll(self, widget, event):
@@ -219,6 +203,12 @@ class Annotations(object):
 
 
 class Media(object):
+    """ Class managing statically the medias and media player backends, to enable play/pause callbacks.
+
+    Args:
+        builder (:class:`~pympress.builder.Builder`): A builder from which to load widgets
+        conf (:class:`~pympress.config.Config`): An object containing the preferences
+    """
     #: `dict` of :class:`~pympress.media_overlays.base.VideoOverlay` ready to be added on top of the slides
     _media_overlays = {}
 
@@ -229,18 +219,13 @@ class Media(object):
 
     #: static `bool` tracking whether we've already done the one-time setup
     _backends_setup = False
-    #: `dict` of mime type as `str` to the `type` of a class inheriting from :class:`~pympress.media_overlays.base.VideoOverlay`
+    #: `dict` containing the mapping from mime types (as `str`)
+    #: to classes inheriting from :class:`~pympress.media_overlays.base.VideoOverlay`
     _backends = {}
     # `list` of info on backend versions
     _backend_versions = []
 
     def __init__(self, builder, conf):
-        """ Set up the required widgets and queue an initial draw.
-
-        Args:
-            builder (:class:`~pympress.builder.Builder`): A builder from which to load widgets
-            conf (:class:`~pympress.config.Config`): An object containing the preferences
-        """
         super(Media, self).__init__()
         self._setup_backends(conf)
         builder.load_widgets(self)
@@ -283,7 +268,8 @@ class Media(object):
                 factory = self.get_factory(mime_type)
 
                 if not factory:
-                    logger.warning('No available overlay for mime type {}, ignoring media {}'.format(mime_type, filename))
+                    logger.warning('No available overlay for mime type {}, ignoring media {}'
+                                   .format(mime_type, filename))
                     continue
 
                 def get_curryfied_callback(name, media_id = media_id):
@@ -309,7 +295,7 @@ class Media(object):
 
 
     def resize(self, which = None):
-        """ Resize all media overlays that are a child of an overlay
+        """ Resize all media overlays that are a child of an overlay.
         """
         needs_resizing = (which == 'content', which == 'presenter') if which is not None else (True, True)
         for media_id in self._media_overlays:
@@ -332,7 +318,8 @@ class Media(object):
         """ Starts playing a media. Used as a callback.
 
         Args:
-            media_id (`int`): A unique idientifier of the media to start playing
+            media_id (`int`): A unique identifier of the media to start playing
+            button (:class:`~Gtk.Button`): the button clicked to cause the media to play, if any.
         """
         if media_id in self._media_overlays:
             c, p = self._media_overlays[media_id]
@@ -345,7 +332,8 @@ class Media(object):
         """ Stops playing a media and hides the player. Used as a callback.
 
         Args:
-            media_id (`int`): A unique idientifier of the media to start playing
+            media_id (`int`): A unique identifier of the media to start playing
+            button (:class:`~Gtk.Button`): the button clicked to cause the media to stop, if any.
         """
         if media_id in self._media_overlays:
             c, p = self._media_overlays[media_id]
@@ -382,7 +370,7 @@ class Media(object):
 
     @classmethod
     def _setup_backends(cls, conf = None):
-        """ Load the backends for video overlays
+        """ Load the backends for video overlays.
         """
         if cls._backends_setup:
             return
@@ -400,7 +388,9 @@ class Media(object):
             cls._backends['image/svg+xml'] = GifOverlay
             cls._backend_versions.append(version)
 
-        except: logger.exception(_('Video support using {} is disabled.').format('Overlay'))
+        except Exception as e:
+            logger.exception(_('Video support using {} is disabled.').format('Overlay'))
+            logger.info(_('Caused by ') + type(e).__name__ + ': ' + str(e))
 
 
         try:
@@ -417,7 +407,9 @@ class Media(object):
                 if not types_list:
                     cls._backends = defaultdict(lambda: GstOverlay, cls._backends)
 
-        except: logger.exception(_('Video support using {} is disabled.').format('GStreamer'))
+        except Exception as e:
+            logger.error(_("Video support using {} is disabled.").format('GStreamer'))
+            logger.info(_('Caused by ') + type(e).__name__ + ': ' + str(e))
 
 
         try:
@@ -434,7 +426,9 @@ class Media(object):
                 if not types_list:
                     cls._backends = defaultdict(lambda: VlcOverlay, cls._backends)
 
-        except: logger.exception(_("Video support using {} is disabled.").format('VLC'))
+        except Exception as e:
+            logger.error(_("Video support using {} is disabled.").format('VLC'))
+            logger.info(_('Caused by ') + type(e).__name__ + ': ' + str(e))
 
 
     @classmethod
@@ -450,10 +444,10 @@ class Media(object):
 
     @classmethod
     def get_factory(cls, mime_type):
-        """ Returns a class of type :attr:`~_backend`
+        """ Returns a class of type :attr:`~_backend`.
         """
         cls._setup_backends()
-        try: # NB don't get(mime_type, None) so that a default can be set
+        try:  # NB don't get(mime_type, None) so that a default can be set
             return cls._backends[mime_type]
         except KeyError:
             return None
@@ -461,6 +455,8 @@ class Media(object):
 
 
 class Cursor(object):
+    """ Class managing cursors statically for displays, so we can select the mouse cursor with a simple string.
+    """
     #: a static `dict` of :class:`~Gdk.Cursor`s, ready to use
     _cursors = {
         'parent': None,
@@ -477,7 +473,7 @@ class Cursor(object):
 
     @classmethod
     def set_cursor(cls, widget, cursor_name = 'parent'):
-        """ Set the cursor named cursor_name'
+        """ Set the cursor named cursor_name'.
 
         Args:
             widget (:class:`~Gtk.Widget`): The widget triggering the cursor change, used to retrieve a Gdk.Window
@@ -493,6 +489,11 @@ class Cursor(object):
 
 
 class Zoom(object):
+    """ Manage the zoom level (using a cairo matrix), draw area that will be zoomed while it is being selected.
+
+    Args:
+        builder (:class:`~pympress.builder.Builder`): A builder from which to load widgets
+    """
     #: Whether we are displaying the interface to scribble on screen and the overlays containing said scribbles
     zoom_selecting = False
     zoom_points = None
@@ -512,11 +513,6 @@ class Zoom(object):
     clear_cache = lambda: None
 
     def __init__(self, builder):
-        """ Setup all the necessary for zooming
-
-        Args:
-            builder (:class:`~pympress.builder.Builder`): A builder from which to load widgets
-        """
         super(Zoom, self).__init__()
         builder.load_widgets(self)
 
@@ -526,10 +522,11 @@ class Zoom(object):
 
     def delayed_callback_connection(self, scribble_builder):
         """ Connect callbacks later than at init, due to circular dependencies.
+
         Call this when the page_number module is initialized, but before needing the callback.
 
         Args:
-            builder (builder.Builder): The builder from which to load widgets for scribble
+            scribble_builder (builder.Builder): The builder from which to load widgets for scribble
         """
         self.set_scribble_zoomout_sensitive = scribble_builder.get_callback_handler('zoom_stop_button.set_sensitive')
 
@@ -663,7 +660,7 @@ class Zoom(object):
 
                 # make center of drawn rectangle the center of the zoomed slide
                 self.shift = (.5 - self.scale * (xmin + xmax) / 2,
-                                    .5 - self.scale * (ymin + ymax) / 2)
+                              .5 - self.scale * (ymin + ymax) / 2)
             except ZeroDivisionError:
                 self.scale = 1.
                 self.shift = (0, 0)
@@ -717,10 +714,10 @@ class FileWatcher(object):
     """ A class with only static methods that wraps object watchdogs, to trigger callbacks when a file changes.
     """
     #: A :class:`~watchdog.observers.Observer` to watch when the file changes
-    observer = Observer()
+    observer = None
 
     #: A :class:`~watchdog.events.FileSystemEventHandler` to get notified when the file changes
-    monitor = FileSystemEventHandler()
+    monitor = None
 
     # `int` that is a GLib timeout id to delay the callback
     timeout = 0
@@ -757,7 +754,7 @@ class FileWatcher(object):
 
     @classmethod
     def call(cls, callback, *args, **kwargs):
-        """ Call the callback
+        """ Call the callback.
 
         Args:
             callback (`function`): callback to call with all the further arguments
@@ -769,15 +766,19 @@ class FileWatcher(object):
 
     @classmethod
     def stop_watching(cls):
-        """ Remove all files that are being watched
+        """ Remove all files that are being watched.
         """
         cls.observer.unschedule_all()
 
 
     @classmethod
     def start_daemon(cls):
-        """ Start the watchdog observer thread
+        """ Start the watchdog observer thread.
         """
+        if cls.observer is None:
+            cls.observer = Observer()
+            cls.monitor = FileSystemEventHandler()
+
         if not cls.observer.is_alive():
             cls.observer.start()
 
@@ -795,3 +796,6 @@ class FileWatcher(object):
 
         while wait and cls.observer.is_alive():
             cls.observer.join()
+
+        cls.observer = None
+        cls.monitor = None
