@@ -19,7 +19,6 @@
 #       along with this program; if not, write to the Free Software
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
-
 """
 :mod:`pympress.ui` -- GUI management
 ------------------------------------
@@ -37,7 +36,8 @@ from __future__ import print_function, unicode_literals
 import logging
 logger = logging.getLogger(__name__)
 
-import os.path, sys
+import os.path
+import sys
 
 import gi
 import cairo
@@ -104,6 +104,8 @@ class UI(builder.Builder):
     prev_button = None
     #: :class:`~Gtk.ToolButton` big button for touch screens, go to next slide
     next_button = None
+    #: :class:`~Gtk.ToolButton` big button for touch screens, go toggle the pointer
+    laser_button = None
     #: :class:`~Gtk.ToolButton` big button for touch screens, go to scribble on screen
     highlight_button = None
 
@@ -141,7 +143,7 @@ class UI(builder.Builder):
     #: Software-implemented laser pointer, :class:`~pympress.pointer.Pointer`
     laser = None
 
-    #: :class:`~pympress.editable_label.PageNumber` displaying current and max page numbers and setting current page number
+    #: :class:`~pympress.editable_label.PageNumber` displaying and setting current page numbers
     page_number = None
 
     #: :class:`~pympress.editable_label.EstimatedTalkTime` to set estimated/remaining talk time
@@ -228,17 +230,18 @@ class UI(builder.Builder):
         # Adjust default visibility of items
         self.prev_button.set_visible(self.show_bigbuttons)
         self.next_button.set_visible(self.show_bigbuttons)
+        self.laser_button.set_visible(self.show_bigbuttons)
         self.highlight_button.set_visible(self.show_bigbuttons)
         self.p_frame_annot.set_visible(self.show_annotations)
         self.laser.activate_pointermode()
 
 
     def load_icons(self):
-        """ Set the icon list for both windows
+        """ Set the icon list for both windows.
         """
         try:
             icon_list = [GdkPixbuf.Pixbuf.new_from_file(i) for i in util.list_icons()]
-        except Exception as e:
+        except Exception:
             logger.exception('Error loading icons')
             return
 
@@ -269,18 +272,18 @@ class UI(builder.Builder):
         self.show_bigbuttons = self.config.getboolean('presenter', 'show_bigbuttons')
 
         init_checkstates = {
-            'pres_pause':      True,
-            'pres_fullscreen': bool(self.c_win.get_window().get_state() & Gdk.WindowState.FULLSCREEN),
-            'pres_notes':      bool(self.notes_mode),
-            'pres_blank':      self.blanked,
-            'pres_annot':      self.show_annotations,
-            'pres_buttons':    self.show_bigbuttons,
-            'pres_highlight':  False,
+            'pres_pause':            True,
+            'pres_fullscreen':       bool(self.c_win.get_window().get_state() & Gdk.WindowState.FULLSCREEN),
+            'pres_notes':            bool(self.notes_mode),
+            'pres_blank':            self.blanked,
+            'pres_annot':            self.show_annotations,
+            'pres_buttons':          self.show_bigbuttons,
+            'pres_highlight':        False,
 
-            'start_blanked':   self.config.getboolean('content', 'start_blanked'),
-            'start_cwin_full': self.config.getboolean('content', 'start_fullscreen'),
-            'start_pwin_full': self.config.getboolean('presenter', 'start_fullscreen'),
-            'portable_config': self.config.using_portable_config(),
+            'start_blanked':         self.config.getboolean('content', 'start_blanked'),
+            'start_cwin_fullscreen': self.config.getboolean('content', 'start_fullscreen'),
+            'start_pwin_fullscreen': self.config.getboolean('presenter', 'start_fullscreen'),
+            'portable_config':       self.config.using_portable_config(),
         }
 
         for n in init_checkstates:
@@ -313,7 +316,7 @@ class UI(builder.Builder):
 
 
     def setup_screens(self):
-        """ Sets up the position of the windows
+        """ Sets up the position of the windows.
         """
         # If multiple monitors, apply windows to monitors according to config
         screen = self.p_win.get_screen()
@@ -324,7 +327,8 @@ class UI(builder.Builder):
             c_full = self.config.getboolean('content', 'start_fullscreen')
 
             if c_monitor == p_monitor and (c_full or p_full):
-                logger.warning(_("Content and presenter window must not be on the same monitor if you start full screen!"))
+                warning = _('Content and presenter window must not be on the same monitor if you start full screen!')
+                logger.warning(warning)
                 p_monitor = 0 if c_monitor > 0 else 1
         else:
             c_monitor = 0
@@ -332,8 +336,10 @@ class UI(builder.Builder):
             c_full = False
             p_full = False
 
-            if self.config.getboolean('presenter', 'start_fullscreen') or self.config.getboolean('content', 'start_fullscreen'):
-                logger.warning(_("Not starting content or presenter window full screen because there is only one monitor"))
+            if self.config.getboolean('presenter', 'start_fullscreen') \
+                    or self.config.getboolean('content', 'start_fullscreen'):
+                logger.warning(_('Not starting content or presenter window full screen ' +
+                                 'because there is only one monitor'))
 
         p_bounds = screen.get_monitor_geometry(p_monitor)
         self.p_win.move(p_bounds.x, p_bounds.y)
@@ -386,14 +392,13 @@ class UI(builder.Builder):
         We tell the local :class:`~pympress.surfacecache.SurfaceCache` cache about it, so that it can
         invalidate its internal cache for the specified widget and pre-render next pages at a correct size.
 
-        Warning: Some not-explicitely sent signals contain wrong values! Just don't resize in that case,
-        since these always seem to happen after a correct signal that was sent explicitely.
+        Warning: Some not-explicitly sent signals contain wrong values! Just don't resize in that case,
+        since these always seem to happen after a correct signal that was sent explicitly.
 
         Args:
             widget (:class:`~Gtk.Widget`):  the widget which has been resized
             event (:class:`~Gdk.Event`):  the GTK event, which contains the new dimensions of the widget
         """
-
         # Don't trust those
         if not event.send_event:
             return
@@ -426,7 +431,10 @@ class UI(builder.Builder):
 
 
     def redraw_panes(self):
-        """ Handler for :class:`~Gtk.Paned`'s resizing signal, used for delayed drawing events of drawing areas inside the panes.
+        """ Handler for :class:`~Gtk.Paned`'s resizing signal.
+
+        Used for delayed drawing events of drawing areas inside the panes.
+
         This is very useful on windows where resizing gets sluggish if we try to redraw while resizing.
         """
         self.resize_panes = False
@@ -437,19 +445,16 @@ class UI(builder.Builder):
         if self.redraw_timeout:
             self.redraw_timeout = 0
 
-        # Temporarily, while p_frame_annot's configure-event is not working
-        self.annotations.on_configure_annot(self.p_frame_annot, None)
-
 
     def on_pane_event(self, widget, evt):
-        """ Signal handler for gtk.paned events
+        """ Signal handler for gtk.paned events.
 
-        This function allows to delay drawing events when resizing, and to speed up redrawing when
+        This function allows one to delay drawing events when resizing, and to speed up redrawing when
         moving the middle pane is done (which happens at the end of a mouse resize)
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occured (ignored)
-            evt (:class:`~Gdk.Event`):  the event that occured
+            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred (ignored)
+            evt (:class:`~Gdk.Event`):  the event that occurred
         """
         if type(evt) == Gdk.EventButton and evt.type == Gdk.EventType.BUTTON_RELEASE:
             self.redraw_panes()
@@ -473,6 +478,9 @@ class UI(builder.Builder):
     def save_and_quit(self, *args):
         """ Save configuration and exit the main loop.
         """
+        if self.p_win.in_destruction() or self.c_win.in_destruction():
+            return
+
         self.scribbler.disable_scribbling()
         self.medias.hide_all()
 
@@ -486,6 +494,8 @@ class UI(builder.Builder):
             util.set_screensaver(False, self.c_win.get_window())
 
         self.config.save_config()
+        self.p_win.destroy()
+        self.c_win.destroy()
         Gtk.main_quit()
 
 
@@ -497,18 +507,19 @@ class UI(builder.Builder):
         about = Gtk.AboutDialog(transient_for = self.p_win)
         pympress = util.get_pympress_meta()
         about.set_program_name('pympress')
-        about.set_version(pympress.__version__)
-        about.set_copyright(_('Contributors:') + '\n' + pympress.__author__)
-        about.set_comments(_('pympress is a little PDF reader written in Python using Poppler for PDF rendering and GTK for the GUI.\n')
-                         + _('Some preferences are saved in ') + self.config.path_to_config() + '\n'
-                         + _('Resources are loaded from ') + os.path.dirname(util.get_locale_dir()) + '\n'
-                         + _('The log is written to ') + util.get_log_path() + '\n\n'
-                         + (_('Media support uses {}.').format(self.medias.backend_version())) + '\n'
-                         + _('Python version {}').format(sys.version))
+        about.set_version(pympress['version'])
+        about.set_copyright(_('Contributors:') + '\n' + pympress['contributors'])
+        about.set_comments(_('pympress is a little PDF reader written in Python ' +
+                             'using Poppler for PDF rendering and GTK for the GUI.\n') +
+                           _('Some preferences are saved in ') + self.config.path_to_config() + '\n' +
+                           _('Resources are loaded from ') + os.path.dirname(util.get_locale_dir()) + '\n' +
+                           _('The log is written to ') + util.get_log_path() + '\n\n' +
+                           _('Media support uses {}.').format(self.medias.backend_version()) + '\n' +
+                           _('Python version {}').format(sys.version))
         about.set_website('https://github.com/Cimbali/pympress')
         try:
             about.set_logo(GdkPixbuf.Pixbuf.new_from_file(util.get_icon_path('pympress-128.png')))
-        except Exception as e:
+        except Exception:
             logger.exception(_('Error loading icon for about window'))
         about.run()
         about.destroy()
@@ -519,7 +530,7 @@ class UI(builder.Builder):
     ##############################################################################
 
     def swap_document(self, docpath, page = 0, reloading = False):
-        """ Replace the currently open document with a new one
+        """ Replace the currently open document with a new one.
 
         The new document is possibly and EmptyDocument if docpath is None.
         The state of the ui and cache are updated accordingly.
@@ -537,20 +548,21 @@ class UI(builder.Builder):
                 extras.FileWatcher.watch_file(docpath, self.reload_document)
 
         except GLib.Error:
-            if reloading: return
+            if reloading:
+                return
             self.doc = document.Document.create(self, None)
             self.error_opening_file(docpath)
             extras.FileWatcher.stop_watching()
 
         # Guess notes mode by default if the document has notes
         if not reloading:
-            target_mode = self.chosen_notes_mode = self.doc.guess_notes()
+            hpref = self.config.get('notes position', 'horizontal')
+            vpref = self.config.get('notes position', 'vertical')
+            self.chosen_notes_mode = target_mode = self.doc.guess_notes(hpref, vpref)
 
-            # Special cases: don't let us toggle with NONE, give A4 documents the benefit of the doubt?
+            # don't toggle from NONE to NONE
             if self.chosen_notes_mode == document.PdfPage.NONE:
                 self.chosen_notes_mode = document.PdfPage.RIGHT
-            elif self.chosen_notes_mode == document.PdfPage.BOTTOM:
-                target_mode = document.PdfPage.NONE
 
             if self.notes_mode != target_mode:
                 self.switch_mode('swap_document', docpath, target_mode = target_mode)
@@ -594,11 +606,11 @@ class UI(builder.Builder):
         Args:
             widget (:class:`~Gtk.Widget`): The widget on which the dragged item was dropped
             drag_context (:class:`~Gdk.DragContext`):
-            x (`float`):
-            y (`float`):
+            x (`float`): position of the drop
+            y (`float`):  position of the drop
             data (:class:`~Gtk.SelectionData`): container for the dropped data
-            info (`int`):
-            time (`int`):
+            info (`int`): info on the target
+            time (`int`): time of the drop
         """
         received = data.get_text()
         if received.startswith('file://'):
@@ -631,7 +643,6 @@ class UI(builder.Builder):
 
         response = dialog.run()
 
-        path = None
         if response == Gtk.ResponseType.OK:
             self.swap_document(os.path.abspath(dialog.get_filename()))
 
@@ -643,11 +654,11 @@ class UI(builder.Builder):
         """
         # Check if the path is valid
         if not os.path.exists(filename):
-            msg=_('Could not find the file "{}"').format(filename)
+            msg = _('Could not find the file "{}"').format(filename)
         else:
-            msg=_('Error opening the file "{}"').format(filename)
+            msg = _('Error opening the file "{}"').format(filename)
         dialog = Gtk.MessageDialog(transient_for = self.p_win, flags = Gtk.DialogFlags.MODAL,
-                                    message_type = Gtk.MessageType.ERROR, message_format = msg)
+                                   message_type = Gtk.MessageType.ERROR, message_format = msg)
         dialog.add_buttons(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
         dialog.set_position(Gtk.WindowPosition.CENTER)
         dialog.run()
@@ -683,7 +694,7 @@ class UI(builder.Builder):
         """
         try:
             widget.set_value(int(widget.get_buffer().get_text()))
-        except:
+        except Exception:
             pass
 
         page_nb = int(widget.get_value()) - 1
@@ -719,7 +730,7 @@ class UI(builder.Builder):
         cur = page_cur.number()
         page_max = min(self.doc.pages_number(), cur + 5)
         page_min = max(0, cur - 2)
-        for p in list(range(cur+1, page_max)) + list(range(cur, page_min, -1)):
+        for p in list(range(cur + 1, page_max)) + list(range(cur, page_min, -1)):
             self.cache.prerender(p)
 
 
@@ -778,7 +789,7 @@ class UI(builder.Builder):
         # Prerender the 4 next pages and the 2 previous ones
         page_max = min(self.doc.pages_number(), self.page_preview_nb + 5)
         page_min = max(0, self.page_preview_nb - 2)
-        for p in list(range(self.page_preview_nb+1, page_max)) + list(range(self.page_preview_nb, page_min, -1)):
+        for p in list(range(self.page_preview_nb + 1, page_max)) + list(range(self.page_preview_nb, page_min, -1)):
             self.cache.prerender(p)
 
         self.medias.replace_media_overlays(self.doc.current_page(), page_type)
@@ -796,7 +807,6 @@ class UI(builder.Builder):
             widget (:class:`~Gtk.Widget`):  the widget to update
             cairo_context (:class:`~cairo.Context`):  the Cairo context (or `None` if called directly)
         """
-
         if widget is self.c_da:
             # Current page
             if self.blanked:
@@ -819,8 +829,8 @@ class UI(builder.Builder):
         wtype = self.cache.get_widget_type(name)
         ww, wh = widget.get_allocated_width(), widget.get_allocated_height()
 
-        if self.zoom.scale != 1. and (widget is self.p_da_cur or widget is self.c_da
-                                      or widget is self.scribbler.scribble_p_da):
+        if self.zoom.scale != 1. and (widget is self.p_da_cur or widget is self.c_da or
+                                      widget is self.scribbler.scribble_p_da):
             zoom_matrix = self.zoom.get_matrix(ww, wh)
             name += '_zoomed'
         else:
@@ -871,7 +881,7 @@ class UI(builder.Builder):
 
 
     def redraw_current_slide(self):
-        """ Callback to queue a redraw of the current slides (in both winows)
+        """ Callback to queue a redraw of the current slides (in both winows).
         """
         self.c_da.queue_draw()
         self.p_da_cur.queue_draw()
@@ -883,11 +893,11 @@ class UI(builder.Builder):
     ##############################################################################
 
     def on_navigation(self, widget, event):
-        """ Manage key presses for both windows
+        """ Manage key presses for both windows.
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occured (ignored)
-            event (:class:`~Gdk.Event`):  the event that occured
+            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred (ignored)
+            event (:class:`~Gdk.Event`):  the event that occurred
 
         Returns:
             `bool`: whether the event was consumed
@@ -968,9 +978,9 @@ class UI(builder.Builder):
             self.laser.toggle_pointermode()
         else:
             if command:
-                logger.error('ERROR: missing command "{}" for {}{}{}{}'.format(command,
-                    'ctrl + ' if ctrl_pressed else '', 'shift + ' if shift_pressed else '',
-                    'meta + ' if meta_pressed else '', name))
+                logger.error('ERROR: missing command "{}" for {}{}{}{}'.format(command,  # noqa: E128
+                             'ctrl + ' if ctrl_pressed else '', 'shift + ' if shift_pressed else '',
+                             'meta + ' if meta_pressed else '', name))
 
             return False
 
@@ -978,11 +988,11 @@ class UI(builder.Builder):
 
 
     def on_scroll(self, widget, event):
-        """ Manage scroll events
+        """ Manage scroll events.
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occured (ignored)
-            event (:class:`~Gdk.Event`):  the event that occured
+            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred (ignored)
+            event (:class:`~Gdk.Event`):  the event that occurred
 
         Returns:
             `bool`: whether the event was consumed
@@ -1000,7 +1010,7 @@ class UI(builder.Builder):
 
 
     def track_motions(self, widget, event):
-        """ Track mouse motion events
+        """ Track mouse motion events.
 
         Handles mouse motions on the "about" menu.
 
@@ -1022,7 +1032,7 @@ class UI(builder.Builder):
 
 
     def track_clicks(self, widget, event):
-        """ Track mouse press and release events
+        """ Track mouse press and release events.
 
         Handles clicks on the slides.
 
@@ -1045,16 +1055,16 @@ class UI(builder.Builder):
 
     def click_link(self, widget, event):
         """ Check whether a link was clicked and follow it.
+
         Handles a click on a slide.
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occured
-            event (:class:`~Gdk.Event`):  the event that occured
+            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred
+            event (:class:`~Gdk.Event`):  the event that occurred
 
         Returns:
             `bool`: whether the event was consumed
         """
-
         if event.type == Gdk.EventType.BUTTON_RELEASE:
             return False
 
@@ -1078,17 +1088,15 @@ class UI(builder.Builder):
 
 
     def hover_link(self, widget, event):
-        """ Manage events related to hyperlinks, setting the cursor to a pointer if
-        the hovered region is clickable.
+        """ Manage events related to hyperlinks, setting the cursor to a pointer if the hovered region is clickable.
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occured
-            event (:class:`~Gdk.Event`):  the event that occured
+            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred
+            event (:class:`~Gdk.Event`):  the event that occurred
 
         Returns:
             `bool`: whether the event was consumed
         """
-
         if event.type != Gdk.EventType.MOTION_NOTIFY:
             return False
 
@@ -1112,14 +1120,13 @@ class UI(builder.Builder):
 
 
     def switch_fullscreen(self, widget):
-        """ Switch the Content window to fullscreen (if in normal mode)
-        or to normal mode (if fullscreen).
+        """ Switch the Content window to fullscreen (if in normal mode) or to normal mode (if fullscreen).
 
         Screensaver will be disabled when entering fullscreen mode, and enabled
         when leaving fullscreen mode.
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occured
+            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred
 
         Returns:
             `bool`: whether some window's full screen status got toggled
@@ -1154,8 +1161,8 @@ class UI(builder.Builder):
         """ Track whether the preview window is maximized.
 
         Args:
-            widget (:class:`~Gtk.Widget`):  the widget in which the event occured
-            event (:class:`~Gtk.Event`):  the event that occured
+            widget (:class:`~Gtk.Widget`):  the widget in which the event occurred
+            event (:class:`~Gtk.Event`):  the event that occurred
 
         Returns:
             `bool`: whether the event was consumed.
@@ -1167,11 +1174,11 @@ class UI(builder.Builder):
 
 
     def update_frame_position(self, widget, user_data):
-        """ Callback to preview the frame alignement, called from the Gtk.SpinButton.
+        """ Callback to preview the frame alignment, called from the Gtk.SpinButton.
 
         Args:
-            widget (:class:`~Gtk.SpinButton`): The button updating the slide alignement in the drawing area widget
-            user_data (`str`): The property being set, either the x or y alignement (resp. xalign and yalign).
+            widget (:class:`~Gtk.SpinButton`): The button updating the slide alignment in the drawing area widget
+            user_data (`str`): The property being set, either the x or y alignment (resp. xalign and yalign).
         """
         self.c_frame.set_property(user_data, widget.get_value())
 
@@ -1211,10 +1218,10 @@ class UI(builder.Builder):
 
 
     def show_timing_report(self, *args):
-        ''' Show the popup with information on timing of the talk.
+        """ Show the popup with information on timing of the talk.
 
         Gather current time, document structure, page labels etc. and pass it to timing popup for display.
-        '''
+        """
         self.timing.show(int(self.talk_time.delta), self.doc.get_structure(), self.doc.page_labels)
 
 
@@ -1245,7 +1252,7 @@ class UI(builder.Builder):
         if (p_win_state & Gdk.WindowState.MAXIMIZED) != 0:
             self.p_win.unmaximize()
 
-        p_monitor, c_monitor = (c_monitor, p_monitor)
+        p_monitor, c_monitor = c_monitor, p_monitor
 
         cx, cy, cw, ch = self.c_win.get_position() + self.c_win.get_size()
         px, py, pw, ph = self.p_win.get_position() + self.p_win.get_size()
@@ -1282,7 +1289,7 @@ class UI(builder.Builder):
 
 
     def swap_layout(self, old, new):
-        """ Save the old layout in the prefs, load the new layout
+        """ Save the old layout in the prefs, load the new layout.
 
         Args:
             old (`str`): the name of the layout to save, `None` to use plain or notes automatically
@@ -1302,12 +1309,11 @@ class UI(builder.Builder):
 
 
     def change_notes_pos(self, widget, event = None, force_change = False):
-        """ Switch the display mode to "Notes mode" or "Normal mode" (without notes).
+        """ Switch the position of the nodes in the slide.
 
         Returns:
             `bool`: whether the mode has been toggled.
         """
-
         if issubclass(type(widget), Gtk.CheckMenuItem):
             # if this widget is not the active one do nothing
             if not widget.get_active():
@@ -1326,6 +1332,7 @@ class UI(builder.Builder):
         if target_mode:
             self.chosen_notes_mode = target_mode
             self.get_object('notes_' + target_mode.name.lower()).set_active(True)
+            self.config.set('notes position', target_mode.direction(), target_mode.name.lower())
 
         # Change the notes arrangement if they are enabled or if we are forced to
         if self.notes_mode or force_change:
@@ -1345,7 +1352,7 @@ class UI(builder.Builder):
             # Exit to not risk double-toggling. Button is now in sync and can be toggled again correctly.
             return False
 
-        if not target_mode:
+        if target_mode is None:
             target_mode = document.PdfPage.NONE if self.notes_mode else self.chosen_notes_mode
 
         if target_mode == self.notes_mode:
@@ -1413,12 +1420,13 @@ class UI(builder.Builder):
 
 
     def switch_bigbuttons(self, *args):
-        """ Toggle the display of big buttons (nice for touch screens)
+        """ Toggle the display of big buttons (nice for touch screens).
         """
         self.show_bigbuttons = not self.show_bigbuttons
 
         self.prev_button.set_visible(self.show_bigbuttons)
         self.next_button.set_visible(self.show_bigbuttons)
+        self.laser_button.set_visible(self.show_bigbuttons)
         self.highlight_button.set_visible(self.show_bigbuttons)
         self.config.set('presenter', 'show_bigbuttons', 'on' if self.show_bigbuttons else 'off')
 
